var __create = Object.create;
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __getProtoOf = Object.getPrototypeOf;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toESM = (mod, isNodeMode, target) => (target = mod != null ? __create(__getProtoOf(mod)) : {}, __copyProps(
  isNodeMode || !mod || !mod.__esModule ? __defProp(target, "default", { value: mod, enumerable: true }) : target,
  mod
));
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// packages/zete/src/index.ts
var src_exports = {};
__export(src_exports, {
  zete: () => zete
});
module.exports = __toCommonJS(src_exports);

// packages/zete/src/core.ts
var import_electron = __toESM(require("electron"));
var import_fs = require("fs");
var import_path = require("path");
var devServer = __toESM(require("@zete/dev"));

// packages/zete/src/utils/logging.ts
var import_colors = require("colors");
var tab = "  ";
function parseError(err) {
  const st = err.stack?.split("\n").slice(1);
  return st?.map((stack) => {
    stack = stack.slice(7);
    const $ = {
      at: "",
      loc: ""
    };
    $.loc = (/\([^)]*\)/.exec(stack) || [])[0] || "";
    $.at = stack.replace($.loc, "");
    return $;
  });
}
function error(err) {
  if (typeof err === "string") {
    console.log(`${"(@)".red.bold} ${err.bold}`);
  } else {
    const stacks = parseError(err);
    console.log(`
${" ERROR ".bgRed.black.bold} ${err.message.bold}
`);
    stacks?.forEach((stack) => {
      console.log(`${tab}${"at".gray} ${stack.at}${stack.loc.cyan}`);
    });
    console.log();
  }
}
function warn(message) {
  console.log(`${"(!)".yellow.bold} ${message.bold}`);
}
function success(message) {
  console.log(`${"(\u2714)".green.bold} ${message.bold}`);
}
function info(message) {
  console.log(`${"(i)".blue.bold} ${message.bold}`);
}
function dev(message) {
  console.log(`${"[dev]".gray.bold} ${message.bold}`);
}
var logger = {
  success,
  info,
  error,
  warn,
  parseError,
  dev
};

// packages/zete/src/utils/package.ts
function existsPackage(packageName) {
  try {
    require(packageName);
    return true;
  } catch (e) {
    return false;
  }
}

// packages/zete/src/core.ts
async function zete(config = {}, fn) {
  const port = config.port || 11050;
  if (!existsPackage("electron"))
    logger.error(new Error("Cannot find module 'electron'."));
  config = {
    cwd: process.cwd(),
    pages: "/pages",
    plugins: [],
    win: {
      showWindowAfterLoad: true,
      electron: {
        width: 1600,
        height: 850,
        show: false,
        webPreferences: {
          preload: (0, import_path.join)(config.cwd || process.cwd(), ".zete", "entry.js"),
          nodeIntegration: true
        }
      }
    },
    ...config
  };
  devServer.builder({});
  const waitForBuild = () => new Promise((resolve) => {
    const wait = setInterval(() => {
      if ((0, import_fs.existsSync)((0, import_path.join)(config.cwd, ".zete", "routes.js"))) {
        clearInterval(wait);
        resolve();
      }
    }, 100);
  });
  waitForBuild().then(async () => {
    logger.dev("built successfully");
    await devServer.dev({
      port
    });
    await import_electron.default.app.whenReady();
    (0, import_fs.writeFileSync)((0, import_path.join)(config.cwd, ".zete", "index.html"), (0, import_fs.readFileSync)((0, import_path.join)(__dirname, "../assets/index.html")));
    (0, import_fs.writeFileSync)((0, import_path.join)(config.cwd, ".zete", "entry.js"), (0, import_fs.readFileSync)((0, import_path.join)(__dirname, "../assets/entry.js")));
    const create = () => {
      const mainWindow = new import_electron.default.BrowserWindow({
        ...config.win.electron
      });
      if (fn)
        fn(mainWindow);
      mainWindow.once("ready-to-show", () => {
        mainWindow.show();
      });
      mainWindow.loadURL(`http://localhost:${port}`);
    };
    create();
    import_electron.default.app.on("activate", () => {
      if (import_electron.default.BrowserWindow.getAllWindows().length === 0) {
        create();
      }
    });
    import_electron.default.app.on("window-all-closed", () => {
      if (process.platform !== "darwin")
        import_electron.default.app.quit();
    });
  });
}
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  zete
});
